import 'package:example/main.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:patrol/patrol.dart';

void main() {
  patrolTest('webview can be opened after granting permission', ($) async {
    await $.pumpWidgetAndSettle(const MyApp());

    // find button with 'Show widget' text
    expect($('Show widget'), findsOneWidget);

    // tap on button
    await $('Show widget').tap();

    expect($(ScannerWidgetScreen), findsOneWidget);

    expect($(CircularProgressIndicator), findsOneWidget);

    // grant permission for camera usage
    await $.native.grantPermissionWhenInUse();

    await $.pumpAndSettle(duration: const Duration(seconds: 5));

    // for testing if webview is in screen, we should check if loading indicator
    // and grant permission's button are not rendered
    expect($(CircularProgressIndicator), findsNothing);
    expect($('Grant camera permission'), findsNothing);
  });

  patrolTest('button with request renders when no permission is granted',
      ($) async {
    await $.pumpWidgetAndSettle(const MyApp());

    // find button with 'Show widget' text
    expect($('Show widget'), findsOneWidget);

    // tap on button
    await $('Show widget').tap();

    expect($(ScannerWidgetScreen), findsOneWidget);

    expect($(CircularProgressIndicator), findsOneWidget);

    // deny permission for camera usage
    await $.native.denyPermission();

    await $.pumpAndSettle(duration: const Duration(seconds: 5));

    expect($(CircularProgressIndicator), findsNothing);
    expect($('Grant camera permission'), findsOneWidget);
  });
}
