import 'package:flutter/material.dart';
import 'package:insurance_card_scanner/insurance_card_scanner.dart';
import 'package:insurance_card_scanner/models/card_scan_messages.dart';

typedef ScanErrorCallback = Function(String?);
typedef ScanSuccessCallback = Function(ScannedCard);

/// Properties and callbacks set to CardScanner
class CardScanConfig {
  const CardScanConfig({
    required this.sessionToken,
    required this.onSuccess,
    this.live = false,
    this.onCardScanCancel,
    this.onCardScanError,
    this.backsideSupport = false,
    this.onCardScanRetry,
    this.messages,
    this.messageStyle,
    this.autoSwitchActiveColor,
    this.autoSwitchInactiveColor,
    this.progressBarColor,
    this.widgetBackgroundColor,
    this.debug = false,
    this.onWebViewLoadError,
  });

  /// JWT used for authenticating users during CardScanner API requests.
  ///
  /// See more: https://docs.cardscan.ai/authentication
  final String sessionToken;

  /// Callback on successful card scanning. Returns a [ScannedCard] object when
  /// triggered.
  final ScanSuccessCallback? onSuccess;

  /// Flag for current environment of the card scanner.
  ///
  /// If `true`, the production environment will be set. Otherwise, the sandbox
  /// environment will be used.
  final bool live;

  /// Callback triggered when user cancels/closes the CardScanner UI.
  final VoidCallback? onCardScanCancel;

  /// Callback triggered on potential errors. Errors happend when calling the
  /// API or when CardScanner fails to initialize.
  final ScanErrorCallback? onCardScanError;

  /// Enable scanning of the front and back side of the card.
  ///
  /// If set to false, the CardScanner will only expect to scan the front side
  /// of a card.
  final bool backsideSupport;

  /// Callback triggered when a scan fails.
  final VoidCallback? onCardScanRetry;

  /// Custom texts for giving visual feedback inside CardScanner UI.
  final CardScanMessages? messages;

  /// Adjust text properties to the message prompted by the UI.
  final TextStyle? messageStyle;

  /// Enabled color for the auto scan switch.
  final Color? autoSwitchActiveColor;

  /// Disabled color for the auto scan switch.
  final Color? autoSwitchInactiveColor;

  /// Color for the progress bar and bounding box surrounding the card scan area.
  final Color? progressBarColor;

  /// Main background color for the widget.
  final Color? widgetBackgroundColor;

  /// Should debug logs be output in JS console
  final bool debug;

  final VoidCallback? onWebViewLoadError;
}
