/// Texts and labels displayed in UI in some scenarios of the scanning process.
///
/// See more: https://docs.cardscan.ai/ui-components/customization#message-customization
class CardScanMessages {
  const CardScanMessages({
    this.autoCaptureTitle,
    this.manualCaptureTitle,
    this.processingTitle,
    this.frontSideCompletedTitle,
    this.completedTitle,
    this.retryTitle,
    this.errorTitle,
    this.cameraErrorTitle,
  });

  /// Message displayed when scanner is waiting for card detection.
  final String? autoCaptureTitle;

  /// Message displayed near camera button when manual scanning is enabled.
  final String? manualCaptureTitle;

  /// Message displayed during scan process.
  final String? processingTitle;

  /// Feedback message shown when scanning for both sides of card is enabled.
  final String? frontSideCompletedTitle;

  /// Message shown when scanning process has been completed.
  final String? completedTitle;

  /// Message shown when scanning process failed.
  final String? retryTitle;

  /// Message shown when CardScan setup failed.
  final String? errorTitle;

  /// Message shown when camera is not available for CardScan.
  final String? cameraErrorTitle;

  /// Shapes object into a Map format
  Map<String, dynamic> toJson() => {
        'autoCaptureTitle': autoCaptureTitle,
        'manualCaptureTitle': manualCaptureTitle,
        'processingTitle': processingTitle,
        'frontsideCompletedTitle': frontSideCompletedTitle,
        'completedTitle': completedTitle,
        'retryTitle': retryTitle,
        'errorTitle': errorTitle,
        'cameraErrorTitle': cameraErrorTitle,
      };
}
