// snippet for web console logging into Flutter console
// user must subscribe to `messageHandler` channel in dart code
import 'dart:convert';

import 'package:insurance_card_scanner/models/card_scan_config.dart';
import 'package:insurance_card_scanner/utils/color_extensions.dart';

// replace logs with callbacks
const _captureConsole = '''
    var oldLog = console.log;
    console.log = function (message) {
      const _message = {
        command: 'console.log',
        message: message
      }
      FlutterWebView.postMessage(JSON.stringify(message));
      oldLog.apply(console, arguments);
    };

    var oldDebug = console.debug;
    console.debug = function (message) {
      const _message = {
        command: 'console.debug',
        message: message
      }
      FlutterWebView.postMessage(JSON.stringify(message));
      oldDebug.apply(console, arguments);
    };

    var oldError = console.error;
    console.error = function (message) {
      const _message = {
        command: 'console.error',
        message: message
      }
      FlutterWebView.postMessage(JSON.stringify(message));
      oldError.apply(console, arguments);
    };
''';

/// Snippet for js injection in web view
String jsSnippet(CardScanConfig properties) {
  final config = {
    "live": properties.live,
    "debug": properties.debug,
    "sessionToken": properties.sessionToken,
    "backsideSupport": properties.backsideSupport,
    "autoSwitchActiveColor": properties.autoSwitchActiveColor?.toCSSHex(),
    "autoSwitchInactiveColor": properties.autoSwitchInactiveColor?.toCSSHex(),
    "progressBarColor": properties.progressBarColor?.toCSSHex(),
    "messages": properties.messages?.toJson(),
    "messageFontSize": '${properties.messageStyle?.fontSize}',
    "messageTextColor": properties.messageStyle?.color?.toCSSHex(),
    "messageBackgroundColor":
        properties.messageStyle?.backgroundColor?.toCSSHex(),
    "enableCameraPermissionModal": false,
  };

  return '''
if (window.loadCardScanView != undefined) {
  window.loadCardScanView('${jsonEncode(config)}');
  console.debug("loadCardScanView - call directly");
} else {
  console.debug("loadCardScanView - create event listener");
  window.addEventListener('CardScanViewLoaded', function (e) {
    console.log(progressBarColor);
    window.loadCardScanView('${jsonEncode(config)}');
    });

}

$_captureConsole
    
//setup error monitoring
window.addEventListener('error', function (e) {
  const message = {
    command: 'syserror',
    message: e.message
  }
  // window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(message));
  FlutterWebView.postMessage(JSON.stringify(message));
});
    
console.debug("injectedJavaScript -- complete");
                ''';
}
