import 'package:flutter/material.dart';
import 'package:insurance_card_scanner/models/card_scan_config.dart';
import 'package:insurance_card_scanner/widgets/scanner_web_view.dart';
import 'package:permission_handler/permission_handler.dart';

/// Widget that contains the UI for scanning cards.
///
/// This widget handles by itself camera permission request operations. However,
/// users should follow corresponding native setup in AndroidManifest.xml and
/// Info.plist. You can follow the next link for better explanation:
/// https://pub.dev/packages/permission_handler
class CardScanner extends StatefulWidget {
  /// Object that contains all properties and callbacks that CardScanner widget
  /// should include
  final CardScanConfig properties;

  const CardScanner({super.key, required this.properties});

  @override
  State<CardScanner> createState() => _CardScannerState();
}

class _CardScannerState extends State<CardScanner> {
  // card scanner requires device's camera
  PermissionStatus? cameraPermissionStatus;

  // camera permission request
  Future<void> requestCameraPermission() async {
    // local variable for status, since we want UI to update after
    // permission has been set from permission_handler's modal form
    var permissionStatus = await Permission.camera.status;

    if (permissionStatus.isGranted) {
      // permission granted, web view is shown
      setState(() => cameraPermissionStatus = permissionStatus);
    } else {
      // permission is not granted yet, so it is requested
      permissionStatus = await Permission.camera.request();

      // set permission status whether is granted or not
      setState(() => cameraPermissionStatus = permissionStatus);
    }
  }

  @override
  void initState() {
    super.initState();
    requestCameraPermission();
  }

  @override
  Widget build(BuildContext context) {
    // local variable inside build for skipping tedious null-safety checks
    final permission = cameraPermissionStatus;

    if (permission == null) {
      return const Center(
        child: CircularProgressIndicator(),
      );
    }

    if (!permission.isGranted) {
      return Center(
        child: TextButton(
          onPressed: requestCameraPermission,
          child: const Text('Grant camera permission'),
        ),
      );
    }

    return ScannerWebView(properties: widget.properties);
  }
}
