import 'package:flutter/material.dart';
import 'package:insurance_card_scanner/models/card_scan_config.dart';
import 'package:insurance_card_scanner/widgets/card_scanner.dart';

/// Modal wrapping the [CardScanner] widget with a custom
/// [transitionAnimationDuration]

class CardScanModal extends ModalRoute<void> {
  final CardScanConfig properties;
  final Duration transitionAnimationDuration;

  CardScanModal({
    required this.properties,
    this.transitionAnimationDuration = const Duration(milliseconds: 200),
  });

  @override
  Duration get transitionDuration => transitionAnimationDuration;

  @override
  bool get opaque => false;

  @override
  bool get barrierDismissible => false;

  @override
  Color get barrierColor => Colors.black.withOpacity(0.5);

  @override
  String get barrierLabel => '';

  @override
  bool get maintainState => true;

  @override
  Widget buildTransitions(
    BuildContext context,
    Animation<double> animation,
    Animation<double> secondaryAnimation,
    Widget child,
  ) {
    return FadeTransition(
      opacity: animation,
      child: ScaleTransition(
        scale: animation,
        child: child,
      ),
    );
  }

  @override
  Widget buildPage(
    BuildContext context,
    Animation<double> animation,
    Animation<double> secondaryAnimation,
  ) {
    // This makes sure that text and other content follows the material style
    return Material(
      type: MaterialType.transparency,
      // make sure that the overlay content is not cut off
      child: SafeArea(
        child: CardScanner(properties: properties),
      ),
    );
  }
}
